# NQDM

<img width="390" alt="logo1" src="https://user-images.githubusercontent.com/46201716/117867669-f2032e80-b298-11eb-89dc-9f57bd0affb5.png">

A more generalised implementation to TQDM-progress bars, 
which simulates a single loop for multiple loops and returns 
multiple elements at the same time. It can iterate over the deeper levels. It is compatible with many data types, 
is customizable and beginner-friendly.

### Installing

Install it using the terminal

```
pip install nqdm
```


Then import it as follows

```
from nqdm import nqdm
```

## Get Started

Please check *main.ipynb* for use cases 

## Built With

* [tqdm](https://github.com/tqdm/tqdm) - The progress bar

## Authors

* **Yamac Eren Ay** - *Initial work* - [yamaceay](https://github.com/yamaceay)

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Special Thanks to:

* **Stanislav Kosorin** - [stano45](https://github.com/stano45) 
* **Ori Toledo** - *Logo design* - [oritoledo](https://github.com/oritoledo)

## Acknowledgments

It's worth mentioning that this module is built on top of [TQDM](https://tqdm.github.io/),  I would like to
thank them for making this process of creating progress bars easy and flexible. 
